[Libreoffice-commits] .: 4 commits - cui/source dbaccess/source helpcontent2 sc/source sd/source svtools/inc svtools/source svx/source

Libreoffice Gerrit user logerrit at kemper.freedesktop.org
Thu Nov 29 18:29:30 PST 2012


 cui/source/customize/cfg.cxx                    |    1 
 cui/source/dialogs/thesdlg.cxx                  |    1 
 dbaccess/source/ui/app/AppDetailView.cxx        |    1 
 dbaccess/source/ui/control/listviewitems.cxx    |    2 
 helpcontent2                                    |    2 
 sc/source/ui/inc/xmlsourcedlg.hxx               |    2 
 sc/source/ui/xmlsource/xmlsourcedlg.cxx         |   22 +++-----
 sd/source/ui/animations/CustomAnimationList.cxx |    1 
 svtools/inc/svtools/treelistbox.hxx             |    9 ---
 svtools/inc/svtools/viewdataentry.hxx           |   21 +++++--
 svtools/source/contnr/svimpbox.cxx              |   49 ------------------
 svtools/source/contnr/svlbitm.cxx               |    1 
 svtools/source/contnr/treelist.cxx              |    1 
 svtools/source/contnr/treelistbox.cxx           |   11 +++-
 svtools/source/contnr/viewdataentry.cxx         |   64 ++++++++++++------------
 svtools/source/uno/treecontrolpeer.cxx          |    1 
 svx/source/dialog/ctredlin.cxx                  |    1 
 svx/source/dialog/fontlb.cxx                    |    1 
 svx/source/form/filtnav.cxx                     |    1 
 19 files changed, 83 insertions(+), 109 deletions(-)

New commits:
commit a013ffa4f71faa77a35352f00bf72195fa7aa499
Author: Kohei Yoshida <kohei.yoshida at gmail.com>
Date:   Thu Nov 29 21:25:53 2012 -0500

    Introduce a 'highlighted' state which differs from a 'selected' state.
    
    And use that to only highlight child entries which should logically be
    treated as not-selected but should have the same appearance as the
    selected entries.
    
    A 'selected' state is logically registered as 'selected' as well as
    visually.  A 'highlighted' state should only appear as if it's selected
    but logically it's treated the same way as non-selected entry.
    
    Change-Id: Ic4bc6923c7678044cf552194ad9865371465c614

diff --git a/sc/source/ui/inc/xmlsourcedlg.hxx b/sc/source/ui/inc/xmlsourcedlg.hxx
index 9139a35..1914df1 100644
--- a/sc/source/ui/inc/xmlsourcedlg.hxx
+++ b/sc/source/ui/inc/xmlsourcedlg.hxx
@@ -56,7 +56,7 @@ class ScXMLSourceDlg : public ScAnyRefDlg
     ScOrcusXMLTreeParam maXMLParam;
     std::set<const SvTreeListEntry*> maCellLinks;
     std::set<const SvTreeListEntry*> maRangeLinks;
-    std::vector<SvTreeListEntry*> maSelectedEntries;
+    std::vector<SvTreeListEntry*> maHighlightedEntries;
 
     boost::scoped_ptr<ScOrcusXMLContext> mpXMLContext;
 
diff --git a/sc/source/ui/xmlsource/xmlsourcedlg.cxx b/sc/source/ui/xmlsource/xmlsourcedlg.cxx
index 013ad69..3a15310 100644
--- a/sc/source/ui/xmlsource/xmlsourcedlg.cxx
+++ b/sc/source/ui/xmlsource/xmlsourcedlg.cxx
@@ -239,23 +239,19 @@ void ScXMLSourceDlg::HandleLoseFocus(Control* /*pCtrl*/)
 
 namespace {
 
-class UnselectEntry : std::unary_function<SvTreeListEntry*, void>
+class UnhighlightEntry : std::unary_function<SvTreeListEntry*, void>
 {
     SvTreeListBox& mrTree;
-    const SvTreeListEntry* mpCurrent;
 public:
-    UnselectEntry(SvTreeListBox& rTree, const SvTreeListEntry* pCur) : mrTree(rTree), mpCurrent(pCur) {}
+    UnhighlightEntry(SvTreeListBox& rTree) : mrTree(rTree) {}
 
     void operator() (SvTreeListEntry* p)
     {
-        if (p == mpCurrent)
-            return;
-
         SvViewDataEntry* pView = mrTree.GetViewDataEntry(p);
         if (!pView)
             return;
 
-        pView->SetSelected(false);
+        pView->SetHighlighted(false);
         mrTree.PaintEntry(p);
     }
 };
@@ -268,11 +264,11 @@ void ScXMLSourceDlg::TreeItemSelected()
     if (!pEntry)
         return;
 
-    if (!maSelectedEntries.empty())
+    if (!maHighlightedEntries.empty())
     {
-        // Unselect highlighted entries that are not currently selected.
-        std::for_each(maSelectedEntries.begin(), maSelectedEntries.end(), UnselectEntry(maLbTree, pEntry));
-        maSelectedEntries.clear();
+        // Remove highlights from all previously highlighted entries (if any).
+        std::for_each(maHighlightedEntries.begin(), maHighlightedEntries.end(), UnhighlightEntry(maLbTree));
+        maHighlightedEntries.clear();
     }
 
     ScOrcusXMLTreeParam::EntryData* pUserData = ScOrcusXMLTreeParam::getUserData(*pEntry);
@@ -424,9 +420,9 @@ void ScXMLSourceDlg::SelectAllChildEntries(SvTreeListEntry& rEntry)
         SvTreeListEntry& r = *it;
         SelectAllChildEntries(r); // select recursively.
         SvViewDataEntry* p = maLbTree.GetViewDataEntry(&r);
-        p->SetSelected(true);
+        p->SetHighlighted(true);
         maLbTree.PaintEntry(&r);
-        maSelectedEntries.push_back(&r);
+        maHighlightedEntries.push_back(&r);
     }
 }
 
diff --git a/svtools/source/contnr/treelistbox.cxx b/svtools/source/contnr/treelistbox.cxx
index b9c4180..945fbb7 100644
--- a/svtools/source/contnr/treelistbox.cxx
+++ b/svtools/source/contnr/treelistbox.cxx
@@ -3007,7 +3007,9 @@ long SvTreeListBox::PaintEntry1(SvTreeListEntry* pEntry,long nLine,sal_uInt16 nT
             int bSelTab = nFlags & SV_LBOXTAB_SHOW_SELECTION;
             sal_uInt16 nItemType = pItem->GetType();
 
-            if ( pViewDataEntry->IsSelected() && bSelTab && !pViewDataEntry->IsCursored() )
+            bool bHighlighted = pViewDataEntry->IsHighlighted() || pViewDataEntry->IsSelected();
+
+            if (bHighlighted && bSelTab && !pViewDataEntry->IsCursored())
             {
                 Color aNewWallColor = rSettings.GetHighlightColor();
                 if ( !bInUse || nItemType != SV_ITEM_ID_LBOXCONTEXTBMP )
diff --git a/svtools/source/contnr/viewdataentry.cxx b/svtools/source/contnr/viewdataentry.cxx
index bcdcb11..a7f1a90 100644
--- a/svtools/source/contnr/viewdataentry.cxx
+++ b/svtools/source/contnr/viewdataentry.cxx
@@ -33,6 +33,7 @@ DBG_NAME(SvViewDataEntry);
 SvViewDataEntry::SvViewDataEntry() :
     nVisPos(0),
     mbSelected(false),
+    mbHighlighted(false),
     mbExpanded(false),
     mbFocused(false),
     mbCursored(false),
@@ -44,6 +45,7 @@ SvViewDataEntry::SvViewDataEntry() :
 SvViewDataEntry::SvViewDataEntry( const SvViewDataEntry& rData ) :
     nVisPos(rData.nVisPos),
     mbSelected(false),
+    mbHighlighted(rData.mbHighlighted),
     mbExpanded(rData.mbExpanded),
     mbFocused(false),
     mbCursored(rData.mbCursored),
@@ -65,6 +67,11 @@ bool SvViewDataEntry::IsSelected() const
     return mbSelected;
 }
 
+bool SvViewDataEntry::IsHighlighted() const
+{
+    return mbHighlighted;
+}
+
 bool SvViewDataEntry::IsExpanded() const
 {
     return mbExpanded;
@@ -100,6 +107,11 @@ void SvViewDataEntry::SetSelected( bool bSelected )
     mbSelected = bSelected;
 }
 
+void SvViewDataEntry::SetHighlighted( bool bHighlighted )
+{
+    mbHighlighted = bHighlighted;
+}
+
 void SvViewDataEntry::SetExpanded( bool bExpanded )
 {
     mbExpanded = bExpanded;
@@ -107,7 +119,7 @@ void SvViewDataEntry::SetExpanded( bool bExpanded )
 
 void SvViewDataEntry::SetSelectable( bool bSelectable )
 {
-    mbSelectable;
+    mbSelectable = bSelectable;
 }
 
 void SvViewDataEntry::Init(size_t nSize)
commit 7a49685adc7e926f320427ee15003acde71053c4
Author: Kohei Yoshida <kohei.yoshida at gmail.com>
Date:   Thu Nov 29 21:06:53 2012 -0500

    I didn't mean to check this in....
    
    Change-Id: I39738ca7fef022a1c9c728cdcd3fa10429a05564

diff --git a/svtools/source/contnr/svimpbox.cxx b/svtools/source/contnr/svimpbox.cxx
index 369fead..6e60207 100644
--- a/svtools/source/contnr/svimpbox.cxx
+++ b/svtools/source/contnr/svimpbox.cxx
@@ -39,48 +39,6 @@
 #define NODE_BMP_TABDIST_NOTVALID   -2000000
 #define FIRST_ENTRY_TAB             1
 
-#include <stdio.h>
-#include <string>
-#include <sys/time.h>
-
-namespace {
-
-class stack_printer
-{
-public:
-    explicit stack_printer(const char *msg) :
-        msMsg(msg)
-    {
-        fprintf(stdout, "%s: --begin\n", msMsg.c_str());
-        mfStartTime = getTime();
-    }
-
-    ~stack_printer()
-    {
-        double fEndTime = getTime();
-        fprintf(stdout, "%s: --end (duration: %g sec)\n", msMsg.c_str(), (fEndTime - mfStartTime));
-    }
-
-    void printTime(int line) const
-    {
-        double fEndTime = getTime();
-        fprintf(stdout, "%s: --(%d) (duration: %g sec)\n", msMsg.c_str(), line, (fEndTime - mfStartTime));
-    }
-
-private:
-    double getTime() const
-    {
-        timeval tv;
-        gettimeofday(&tv, NULL);
-        return tv.tv_sec + tv.tv_usec / 1000000.0;
-    }
-
-    ::std::string msMsg;
-    double mfStartTime;
-};
-
-}
-
 // #i27063# (pl), #i32300# (pb) never access VCL after DeInitVCL - also no destructors
 Image*  SvImpLBox::s_pDefCollapsed      = NULL;
 Image*  SvImpLBox::s_pDefExpanded       = NULL;
@@ -642,7 +600,6 @@ void SvImpLBox::RecalcFocusRect()
 
 void SvImpLBox::SetCursor( SvTreeListEntry* pEntry, bool bForceNoSelect )
 {
-    stack_printer __stack_printer__("SvImpLBox::SetCursor");
     SvViewDataEntry* pViewDataNewCur = 0;
     if( pEntry )
         pViewDataNewCur= pView->GetViewDataEntry(pEntry);
@@ -651,7 +608,6 @@ void SvImpLBox::SetCursor( SvTreeListEntry* pEntry, bool bForceNoSelect )
         pViewDataNewCur->HasFocus() &&
         pViewDataNewCur->IsSelected())
     {
-        fprintf(stdout, "SvImpLBox::SetCursor:   nothing to do\n");
         return;
     }
 
@@ -673,11 +629,9 @@ void SvImpLBox::SetCursor( SvTreeListEntry* pEntry, bool bForceNoSelect )
     pCursor = pEntry;
     if( pCursor )
     {
-        fprintf(stdout, "SvImpLBox::SetCursor:   cp (%d)\n", __LINE__);
         pViewDataNewCur->SetFocus( true );
         if(!bForceNoSelect && bSimpleTravel && !(nFlags & F_DESEL_ALL) && GetUpdateMode())
         {
-            fprintf(stdout, "SvImpLBox::SetCursor:   cp (%d)\n", __LINE__);
             pView->Select( pCursor, true );
         }
         // multiple selection: select in cursor move if we're not in
@@ -687,12 +641,10 @@ void SvImpLBox::SetCursor( SvTreeListEntry* pEntry, bool bForceNoSelect )
                  !(nFlags & F_DESEL_ALL) && !aSelEng.IsAddMode() &&
                  !bForceNoSelect )
         {
-            fprintf(stdout, "SvImpLBox::SetCursor:   cp (%d)\n", __LINE__);
             pView->Select( pCursor, true );
         }
         else
         {
-            fprintf(stdout, "SvImpLBox::SetCursor:   cp (%d)\n", __LINE__);
             ShowCursor( true );
         }
 
commit dcfcf711b6631fd018aa755000d6b93040ae0382
Author: Kohei Yoshida <kohei.yoshida at gmail.com>
Date:   Thu Nov 29 20:50:06 2012 -0500

    Use bitfield for better readability.
    
    Change-Id: Iaa254703be5f798e749eaccfa3b7136e26054b65

diff --git a/svtools/inc/svtools/viewdataentry.hxx b/svtools/inc/svtools/viewdataentry.hxx
index 0686088..abd1ead 100644
--- a/svtools/inc/svtools/viewdataentry.hxx
+++ b/svtools/inc/svtools/viewdataentry.hxx
@@ -42,7 +42,11 @@ class SVT_DLLPUBLIC SvViewDataEntry
 
     std::vector<SvViewDataItem> maItems;
     sal_uLong nVisPos;
-    sal_uInt16 nFlags;
+    bool mbSelected:1;
+    bool mbExpanded:1;
+    bool mbFocused:1;
+    bool mbCursored:1;
+    bool mbSelectable:1;
 
 public:
     SvViewDataEntry();
diff --git a/svtools/source/contnr/viewdataentry.cxx b/svtools/source/contnr/viewdataentry.cxx
index 897e0e9..bcdcb11 100644
--- a/svtools/source/contnr/viewdataentry.cxx
+++ b/svtools/source/contnr/viewdataentry.cxx
@@ -31,16 +31,25 @@
 DBG_NAME(SvViewDataEntry);
 
 SvViewDataEntry::SvViewDataEntry() :
-    nVisPos(0), nFlags(0)
+    nVisPos(0),
+    mbSelected(false),
+    mbExpanded(false),
+    mbFocused(false),
+    mbCursored(false),
+    mbSelectable(true)
 {
     DBG_CTOR(SvViewDataEntry,0);
 }
 
 SvViewDataEntry::SvViewDataEntry( const SvViewDataEntry& rData ) :
-    nVisPos(rData.nVisPos), nFlags(rData.nFlags)
+    nVisPos(rData.nVisPos),
+    mbSelected(false),
+    mbExpanded(rData.mbExpanded),
+    mbFocused(false),
+    mbCursored(rData.mbCursored),
+    mbSelectable(rData.mbSelectable)
 {
     DBG_CTOR(SvViewDataEntry,0);
-    nFlags &= ~( SVLISTENTRYFLAG_SELECTED | SVLISTENTRYFLAG_FOCUSED );
 }
 
 SvViewDataEntry::~SvViewDataEntry()
@@ -48,73 +57,57 @@ SvViewDataEntry::~SvViewDataEntry()
     DBG_DTOR(SvViewDataEntry,0);
 #ifdef DBG_UTIL
     nVisPos = 0x12345678;
-    nFlags = 0x1234;
 #endif
 }
 
 bool SvViewDataEntry::IsSelected() const
 {
-    return (nFlags & SVLISTENTRYFLAG_SELECTED) != 0;
+    return mbSelected;
 }
 
 bool SvViewDataEntry::IsExpanded() const
 {
-    return (nFlags & SVLISTENTRYFLAG_EXPANDED) != 0;
+    return mbExpanded;
 }
 
 bool SvViewDataEntry::HasFocus() const
 {
-    return (nFlags & SVLISTENTRYFLAG_FOCUSED) != 0;
+    return mbFocused;
 }
 
 bool SvViewDataEntry::IsCursored() const
 {
-    return (nFlags & SVLISTENTRYFLAG_CURSORED) != 0;
+    return mbCursored;
 }
 
 bool SvViewDataEntry::IsSelectable() const
 {
-    return (nFlags & SVLISTENTRYFLAG_NOT_SELECTABLE) == 0;
+    return mbSelectable;
 }
 
 void SvViewDataEntry::SetFocus( bool bFocus )
 {
-    if ( !bFocus )
-        nFlags &= (~SVLISTENTRYFLAG_FOCUSED);
-    else
-        nFlags |= SVLISTENTRYFLAG_FOCUSED;
+    mbFocused = bFocus;
 }
 
 void SvViewDataEntry::SetCursored( bool bCursored )
 {
-    if ( !bCursored )
-        nFlags &= (~SVLISTENTRYFLAG_CURSORED);
-    else
-        nFlags |= SVLISTENTRYFLAG_CURSORED;
+    mbCursored = bCursored;
 }
 
 void SvViewDataEntry::SetSelected( bool bSelected )
 {
-    if ( !bSelected )
-        nFlags &= (~SVLISTENTRYFLAG_SELECTED);
-    else
-        nFlags |= SVLISTENTRYFLAG_SELECTED;
+    mbSelected = bSelected;
 }
 
 void SvViewDataEntry::SetExpanded( bool bExpanded )
 {
-    if ( !bExpanded )
-        nFlags &= (~SVLISTENTRYFLAG_EXPANDED);
-    else
-        nFlags |= SVLISTENTRYFLAG_EXPANDED;
+    mbExpanded = bExpanded;
 }
 
 void SvViewDataEntry::SetSelectable( bool bSelectable )
 {
-    if( bSelectable )
-        nFlags &= (~SVLISTENTRYFLAG_NOT_SELECTABLE);
-    else
-        nFlags |= SVLISTENTRYFLAG_NOT_SELECTABLE;
+    mbSelectable;
 }
 
 void SvViewDataEntry::Init(size_t nSize)
commit f532752756c81a295116b0889fe4e9d31b7c3bb6
Author: Kohei Yoshida <kohei.yoshida at gmail.com>
Date:   Thu Nov 29 20:39:48 2012 -0500

    Remove unused method & remove header include by using forward declaration.
    
    Also, SvViewDataEntry has lost one friend.
    
    Change-Id: Icf6d4127de38fed485cd260edae97748b1f78ede

diff --git a/cui/source/customize/cfg.cxx b/cui/source/customize/cfg.cxx
index 72e9097..1db51dc 100644
--- a/cui/source/customize/cfg.cxx
+++ b/cui/source/customize/cfg.cxx
@@ -45,6 +45,7 @@
 #include <svtools/miscopt.hxx>
 #include <svtools/svlbitm.hxx>
 #include "svtools/treelistentry.hxx"
+#include "svtools/viewdataentry.hxx"
 #include <tools/diagnose_ex.h>
 #include <toolkit/unohlp.hxx>
 
diff --git a/cui/source/dialogs/thesdlg.cxx b/cui/source/dialogs/thesdlg.cxx
index c0ec800..0c4e1e0 100644
--- a/cui/source/dialogs/thesdlg.cxx
+++ b/cui/source/dialogs/thesdlg.cxx
@@ -28,6 +28,7 @@
 #include <svtools/svlbitm.hxx>
 #include <svtools/treelistbox.hxx>
 #include "svtools/treelistentry.hxx"
+#include "svtools/viewdataentry.hxx"
 #include <vcl/wrkwin.hxx>
 #include <vcl/msgbox.hxx>
 #include <vcl/svapp.hxx>
diff --git a/dbaccess/source/ui/app/AppDetailView.cxx b/dbaccess/source/ui/app/AppDetailView.cxx
index afb6c95..cb26fab 100644
--- a/dbaccess/source/ui/app/AppDetailView.cxx
+++ b/dbaccess/source/ui/app/AppDetailView.cxx
@@ -40,6 +40,7 @@
 #include "moduledbu.hxx"
 #include <svtools/localresaccess.hxx>
 #include "svtools/treelistentry.hxx"
+#include "svtools/viewdataentry.hxx"
 #include <algorithm>
 #include "dbtreelistbox.hxx"
 #include "IApplicationController.hxx"
diff --git a/dbaccess/source/ui/control/listviewitems.cxx b/dbaccess/source/ui/control/listviewitems.cxx
index 7b8c8a0..c98228c 100644
--- a/dbaccess/source/ui/control/listviewitems.cxx
+++ b/dbaccess/source/ui/control/listviewitems.cxx
@@ -19,6 +19,8 @@
 
 
 #include "listviewitems.hxx"
+#include "svtools/viewdataentry.hxx"
+
 //........................................................................
 namespace dbaui
 {
diff --git a/helpcontent2 b/helpcontent2
index 4d46d7e..3dc2e74 160000
--- a/helpcontent2
+++ b/helpcontent2
@@ -1 +1 @@
-Subproject commit 4d46d7ee993ea549cf959bc012a616308b3496c9
+Subproject commit 3dc2e7497f1798ae4ff6c5c8c562666bc10a393c
diff --git a/sd/source/ui/animations/CustomAnimationList.cxx b/sd/source/ui/animations/CustomAnimationList.cxx
index f1d4c78..1fde2cf 100644
--- a/sd/source/ui/animations/CustomAnimationList.cxx
+++ b/sd/source/ui/animations/CustomAnimationList.cxx
@@ -38,6 +38,7 @@
 
 #include "svtools/svlbitm.hxx"
 #include "svtools/treelistentry.hxx"
+#include "svtools/viewdataentry.hxx"
 
 #include "res_bmp.hrc"
 #include "glob.hrc"
diff --git a/svtools/inc/svtools/treelistbox.hxx b/svtools/inc/svtools/treelistbox.hxx
index 3aa8769..ba678ae 100644
--- a/svtools/inc/svtools/treelistbox.hxx
+++ b/svtools/inc/svtools/treelistbox.hxx
@@ -37,7 +37,6 @@
 #include <tools/contnr.hxx>
 #include <svtools/treelist.hxx>
 #include <svtools/transfer.hxx>
-#include "svtools/viewdataentry.hxx"
 
 class Application;
 class SvTreeListBox;
@@ -143,11 +142,7 @@ public:
     virtual             ~SvLBoxItem();
     virtual sal_uInt16 GetType() const = 0;
     const Size&         GetSize(const SvTreeListBox* pView, const SvTreeListEntry* pEntry) const;
-    const Size&         GetSize(const SvViewDataEntry* pData, sal_uInt16 nItemPos) const
-                        {
-                            const SvViewDataItem* pIData = pData->GetItem(nItemPos);
-                            return pIData->maSize;
-                        }
+    const Size&         GetSize(const SvViewDataEntry* pData, sal_uInt16 nItemPos) const;
 
     virtual void Paint(
         const Point& rPos, SvTreeListBox& rOutDev, const SvViewDataEntry* pView, const SvTreeListEntry* pEntry) = 0;
@@ -347,7 +342,7 @@ public:
     SvTreeListBox( Window* pParent, const ResId& rResId );
     virtual ~SvTreeListBox();
 
-    SvTreeList* GetModel() const { return (SvTreeList*)pModel; }
+    SvTreeList* GetModel() const { return pModel; }
     using SvListView::SetModel;
     void SetModel(SvTreeList* pNewModel);
 
diff --git a/svtools/inc/svtools/viewdataentry.hxx b/svtools/inc/svtools/viewdataentry.hxx
index 65a3db9..0686088 100644
--- a/svtools/inc/svtools/viewdataentry.hxx
+++ b/svtools/inc/svtools/viewdataentry.hxx
@@ -39,7 +39,6 @@ struct SvViewDataItem
 class SVT_DLLPUBLIC SvViewDataEntry
 {
     friend class SvTreeList;
-    friend class SvListView;
 
     std::vector<SvViewDataItem> maItems;
     sal_uLong nVisPos;
@@ -59,7 +58,6 @@ public:
     void SetCursored( bool bCursored );
     void SetSelected( bool bSelected );
     void SetExpanded( bool bExpanded );
-    sal_uInt16 GetFlags() const;
     void SetSelectable( bool bSelectable );
 
     void Init(size_t nSize);
diff --git a/svtools/source/contnr/svimpbox.cxx b/svtools/source/contnr/svimpbox.cxx
index d3c0eb7..369fead 100644
--- a/svtools/source/contnr/svimpbox.cxx
+++ b/svtools/source/contnr/svimpbox.cxx
@@ -34,6 +34,7 @@
 #include <comphelper/string.hxx>
 
 #include "svtools/treelistentry.hxx"
+#include "svtools/viewdataentry.hxx"
 
 #define NODE_BMP_TABDIST_NOTVALID   -2000000
 #define FIRST_ENTRY_TAB             1
diff --git a/svtools/source/contnr/svlbitm.cxx b/svtools/source/contnr/svlbitm.cxx
index e0f4b25..10621ef 100644
--- a/svtools/source/contnr/svlbitm.cxx
+++ b/svtools/source/contnr/svlbitm.cxx
@@ -20,6 +20,7 @@
 #include <svtools/treelistbox.hxx>
 #include <svtools/svlbitm.hxx>
 #include "svtools/treelistentry.hxx"
+#include "svtools/viewdataentry.hxx"
 #include <vcl/svapp.hxx>
 #include <vcl/button.hxx>
 #include <vcl/decoview.hxx>
diff --git a/svtools/source/contnr/treelist.cxx b/svtools/source/contnr/treelist.cxx
index 70b410c..d0125f4 100644
--- a/svtools/source/contnr/treelist.cxx
+++ b/svtools/source/contnr/treelist.cxx
@@ -19,6 +19,7 @@
 
 #include "svtools/treelist.hxx"
 #include "svtools/treelistentry.hxx"
+#include "svtools/viewdataentry.hxx"
 #include "osl/diagnose.h"
 
 #include <stdio.h>
diff --git a/svtools/source/contnr/treelistbox.cxx b/svtools/source/contnr/treelistbox.cxx
index 802ec45..b9c4180 100644
--- a/svtools/source/contnr/treelistbox.cxx
+++ b/svtools/source/contnr/treelistbox.cxx
@@ -37,6 +37,7 @@
 #include <svtools/svmedit.hxx>
 #include <svtools/svlbitm.hxx>
 #include "svtools/treelistentry.hxx"
+#include "svtools/viewdataentry.hxx"
 #include "svimpbox.hxx"
 
 #include <set>
@@ -366,6 +367,12 @@ const Size& SvLBoxItem::GetSize(const SvTreeListBox* pView, const SvTreeListEntr
     return pViewData->maSize;
 }
 
+const Size& SvLBoxItem::GetSize(const SvViewDataEntry* pData, sal_uInt16 nItemPos) const
+{
+    const SvViewDataItem* pIData = pData->GetItem(nItemPos);
+    return pIData->maSize;
+}
+
 struct SvTreeListBoxImpl
 {
     bool m_bIsEmptyTextAllowed:1;
diff --git a/svtools/source/contnr/viewdataentry.cxx b/svtools/source/contnr/viewdataentry.cxx
index 1d3bfaf..897e0e9 100644
--- a/svtools/source/contnr/viewdataentry.cxx
+++ b/svtools/source/contnr/viewdataentry.cxx
@@ -109,11 +109,6 @@ void SvViewDataEntry::SetExpanded( bool bExpanded )
         nFlags |= SVLISTENTRYFLAG_EXPANDED;
 }
 
-sal_uInt16 SvViewDataEntry::GetFlags() const
-{
-    return nFlags;
-}
-
 void SvViewDataEntry::SetSelectable( bool bSelectable )
 {
     if( bSelectable )
diff --git a/svtools/source/uno/treecontrolpeer.cxx b/svtools/source/uno/treecontrolpeer.cxx
index f15a223..186490c 100644
--- a/svtools/source/uno/treecontrolpeer.cxx
+++ b/svtools/source/uno/treecontrolpeer.cxx
@@ -34,6 +34,7 @@
 #include <vcl/svapp.hxx>
 #include <svtools/treelistbox.hxx>
 #include "svtools/treelistentry.hxx"
+#include "svtools/viewdataentry.hxx"
 #include <svtools/svlbitm.hxx>
 
 #include <map>
diff --git a/svx/source/dialog/ctredlin.cxx b/svx/source/dialog/ctredlin.cxx
index dec1a03..fabdccc 100644
--- a/svx/source/dialog/ctredlin.cxx
+++ b/svx/source/dialog/ctredlin.cxx
@@ -23,6 +23,7 @@
 #include <sfx2/module.hxx>
 #include <svtools/txtcmp.hxx>
 #include <svtools/svlbitm.hxx>
+#include "svtools/viewdataentry.hxx"
 #include <unotools/charclass.hxx>
 
 #include <editeng/unolingu.hxx>
diff --git a/svx/source/dialog/fontlb.cxx b/svx/source/dialog/fontlb.cxx
index 199a289..fbb39ef 100644
--- a/svx/source/dialog/fontlb.cxx
+++ b/svx/source/dialog/fontlb.cxx
@@ -20,6 +20,7 @@
 #include "svx/fontlb.hxx"
 #include <vcl/svapp.hxx>
 #include "svtools/treelistentry.hxx"
+#include "svtools/viewdataentry.hxx"
 
 // ============================================================================
 
diff --git a/svx/source/form/filtnav.cxx b/svx/source/form/filtnav.cxx
index a03c38f..8fec3cf 100644
--- a/svx/source/form/filtnav.cxx
+++ b/svx/source/form/filtnav.cxx
@@ -56,6 +56,7 @@
 #include <tools/diagnose_ex.h>
 #include <svtools/svlbitm.hxx>
 #include "svtools/treelistentry.hxx"
+#include "svtools/viewdataentry.hxx"
 
 #include <functional>
 


More information about the Libreoffice-commits mailing list
diff --git a/svtools/inc/svtools/viewdataentry.hxx b/svtools/inc/svtools/viewdataentry.hxx
index abd1ead..304b5fa 100644
--- a/svtools/inc/svtools/viewdataentry.hxx
+++ b/svtools/inc/svtools/viewdataentry.hxx
@@ -32,9 +32,13 @@ struct SvViewDataItem
 };
 
 /**
  * View-dependent data for an Entry is created in the virtual function
  * SvTreeListBox::CreateViewData. The View creation of Items should not be
  * changed.
  */
 class SVT_DLLPUBLIC SvViewDataEntry
 {
@@ -43,6 +47,7 @@ class SVT_DLLPUBLIC SvViewDataEntry
     std::vector<SvViewDataItem> maItems;
     sal_uLong nVisPos;
     bool mbSelected:1;
+    bool mbHighlighted:1;
     bool mbExpanded:1;
     bool mbFocused:1;
     bool mbCursored:1;
@@ -54,6 +59,7 @@ public:
     ~SvViewDataEntry();
 
     bool IsSelected() const;
+    bool IsHighlighted() const;
     bool IsExpanded() const;
     bool HasFocus() const;
     bool IsCursored() const;
@@ -61,6 +67,7 @@ public:
     void SetFocus( bool bFocus );
     void SetCursored( bool bCursored );
     void SetSelected( bool bSelected );
+    void SetHighlighted( bool bHighlighted );
     void SetExpanded( bool bExpanded );
     void SetSelectable( bool bSelectable );
 
@@ -32,9 +32,13 @@ struct SvViewDataItem
 
 /**
- * View-dependent data for an Entry is created in the virtual function
- * SvTreeListBox::CreateViewData. The View creation of Items should not be
- * changed.
+ * View-dependent data for a tree list entry created in the virtual function
+ * SvTreeListBox::CreateViewData(). The item array contains the same number
+ * of items as that of the items in its corresponding tree list entry.
+ *
+ * When an entry is selected, it is both logically and visually selected.
+ * When an entry is highlighted, it appears selected visually, but it's not
+ * logically selected.
  */
 class SVT_DLLPUBLIC SvViewDataEntry